@@ -487,13 +487,13 @@ class ResponseObject(object):
 			_sorted_ = Array(path=False, array=list(dictionary.keys())).sort(alphabetical=alphabetical, ascending=ascending, reversed=reversed)
 		else: raise ValueError("Unknown behaviour, alphabetical=False.")
 		for key in _sorted_:
-			new[key] = dictionary[key]
+			new[Formats.denitialize(key)] = dictionary[Formats.denitialize(key)]
 		return new
 	# return self as dict.
 	def dict(self, sorted=False, reversed=False, json=False):
 		dictionary = {}
 		for key in self.keys():
-			dictionary[key] = self[key]
+			dictionary[Formats.denitialize(key)] = self[Formats.denitialize(key)]
 		return self.serialize(json=json, sorted=sorted, reversed=reversed, dictionary=dictionary)
 	# dump json string.
 	def json(self, sorted=False, reversed=False, indent=4, dictionary=None, ):
